[libgweather] location-entry: Subclass GtkSearchEntry



commit 8ac4eae1124cdedc9b93c47a70215e53ef745e0a
Author: Jasper St. Pierre <jstpierre mecheye net>
Date:   Fri Jun 14 23:51:34 2013 -0400

    location-entry: Subclass GtkSearchEntry
    
    This breaks ABI, but this is why we have the "I_KNOW_ITS_UNSTABLE"
    #define.

 libgweather/location-entry.c |    4 ++--
 libgweather/location-entry.h |    7 ++-----
 2 files changed, 4 insertions(+), 7 deletions(-)
---
diff --git a/libgweather/location-entry.h b/libgweather/location-entry.h
index 4f3147e..66ba54d 100644
--- a/libgweather/location-entry.h
+++ b/libgweather/location-entry.h
@@ -36,17 +36,14 @@ typedef struct _GWeatherLocationEntryPrivate GWeatherLocationEntryPrivate;
 #define GWEATHER_LOCATION_ENTRY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), 
GWEATHER_TYPE_LOCATION_ENTRY, GWeatherLocationEntryClass))
 
 struct _GWeatherLocationEntry {
-    GtkEntry parent;
+    GtkSearchEntry parent;
 
     /*< private >*/
     GWeatherLocationEntryPrivate *priv;
-    gpointer backward_compatibility_padding;
-    guint more_padding : 1;
 };
 
 struct _GWeatherLocationEntryClass {
-    GtkEntryClass parent_class;
-
+    GtkSearchEntryClass parent_class;
 };
 
 GType             gweather_location_entry_get_type     (void);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libgweather/location-entry.c b/libgweather/location-entry.c
index 8e5f5c2..aa96da8 100644
--- a/libgweather/location-entry.c
+++ b/libgweather/location-entry.c
@@ -32,7 +32,7 @@
  * SECTION:gweatherlocationentry
  * @Title: GWeatherLocationEntry
  *
  * A subclass of #GtkEntry that provides autocompletion on
  * #GWeatherLocation<!-- -->s
  */
 
@@ -43,7 +43,7 @@ struct _GWeatherLocationEntryPrivate {
     gboolean          custom_text;
 };
 
-G_DEFINE_TYPE (GWeatherLocationEntry, gweather_location_entry, GTK_TYPE_ENTRY)
+G_DEFINE_TYPE (GWeatherLocationEntry, gweather_location_entry, GTK_TYPE_SEARCH_ENTRY)
 
 enum {
     PROP_0,
@@ -32,7 +32,7 @@
  * @Title: GWeatherLocationEntry
  *
- * A subclass of #GtkEntry that provides autocompletion on
+ * A subclass of #GtkSearchEntry that provides autocompletion on
  * #GWeatherLocation<!-- -->s
  */